==> kubernetes-model-core-5.2.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/AWSElasticBlockStoreVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AWSElasticBlockStoreVolumeSourceFluentImpl<A extends AWSElasticBlockStoreVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AWSElasticBlockStoreVolumeSourceFluent<A> {

    private String fsType;
    private Integer partition;
    private Boolean readOnly;
    private String volumeID;

    public AWSElasticBlockStoreVolumeSourceFluentImpl() {
    }

    public AWSElasticBlockStoreVolumeSourceFluentImpl(AWSElasticBlockStoreVolumeSource instance) {
        this.withFsType(instance.getFsType()); 
        this.withPartition(instance.getPartition()); 
        this.withReadOnly(instance.getReadOnly()); 
        this.withVolumeID(instance.getVolumeID()); 
    }

    public String getFsType() {
        return this.fsType;
    }

    public A withFsType(String fsType) {
        this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType() {
        return this.fsType != null;
    }

    public A withNewFsType(String arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuilder arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuffer arg1) {
        return (A)withFsType(new String(arg1));
    }

    public Integer getPartition() {
        return this.partition;
    }

    public A withPartition(Integer partition) {
        this.partition=partition; return (A) this;
    }

    public Boolean hasPartition() {
        return this.partition != null;
    }

    public A withNewPartition(String arg1) {
        return (A)withPartition(new Integer(arg1));
    }

    public A withNewPartition(int arg1) {
        return (A)withPartition(new Integer(arg1));
    }

    public Boolean isReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public String getVolumeID() {
        return this.volumeID;
    }

    public A withVolumeID(String volumeID) {
        this.volumeID=volumeID; return (A) this;
    }

    public Boolean hasVolumeID() {
        return this.volumeID != null;
    }

    public A withNewVolumeID(String arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(StringBuilder arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(StringBuffer arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AWSElasticBlockStoreVolumeSourceFluentImpl that = (AWSElasticBlockStoreVolumeSourceFluentImpl) o;
        if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
        if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        if (volumeID != null ? !volumeID.equals(that.volumeID) :that.volumeID != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fsType,  partition,  readOnly,  volumeID,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/AWSElasticBlockStoreVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AWSElasticBlockStoreVolumeSourceFluentImpl<A extends AWSElasticBlockStoreVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AWSElasticBlockStoreVolumeSourceFluent<A> {

    private String fsType;
    private Integer partition;
    private Boolean readOnly;
    private String volumeID;

    public AWSElasticBlockStoreVolumeSourceFluentImpl() {
    }

    public AWSElasticBlockStoreVolumeSourceFluentImpl(AWSElasticBlockStoreVolumeSource instance) {
        this.withFsType(instance.getFsType()); 
        this.withPartition(instance.getPartition()); 
        this.withReadOnly(instance.getReadOnly()); 
        this.withVolumeID(instance.getVolumeID()); 
    }

    public String getFsType() {
        return this.fsType;
    }

    public A withFsType(String fsType) {
        this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType() {
        return this.fsType != null;
    }

    public A withNewFsType(StringBuilder arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(int[] arg1,int arg2,int arg3) {
        return (A)withFsType(new String(arg1, arg2, arg3));
    }

    public A withNewFsType(char[] arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuffer arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(byte[] arg1,int arg2) {
        return (A)withFsType(new String(arg1, arg2));
    }

    public A withNewFsType(byte[] arg1) {
        return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(char[] arg1,int arg2,int arg3) {
        return (A)withFsType(new String(arg1, arg2, arg3));
    }

    public A withNewFsType(byte[] arg1,int arg2,int arg3) {
        return (A)withFsType(new String(arg1, arg2, arg3));
    }

    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withFsType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewFsType(String arg1) {
        return (A)withFsType(new String(arg1));
    }

    public Integer getPartition() {
        return this.partition;
    }

    public A withPartition(Integer partition) {
        this.partition=partition; return (A) this;
    }

    public Boolean hasPartition() {
        return this.partition != null;
    }

    public A withNewPartition(int arg1) {
        return (A)withPartition(new Integer(arg1));
    }

    public Boolean getReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public String getVolumeID() {
        return this.volumeID;
    }

    public A withVolumeID(String volumeID) {
        this.volumeID=volumeID; return (A) this;
    }

    public Boolean hasVolumeID() {
        return this.volumeID != null;
    }

    public A withNewVolumeID(StringBuilder arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(int[] arg1,int arg2,int arg3) {
        return (A)withVolumeID(new String(arg1, arg2, arg3));
    }

    public A withNewVolumeID(char[] arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(StringBuffer arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(byte[] arg1,int arg2) {
        return (A)withVolumeID(new String(arg1, arg2));
    }

    public A withNewVolumeID(byte[] arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public A withNewVolumeID(char[] arg1,int arg2,int arg3) {
        return (A)withVolumeID(new String(arg1, arg2, arg3));
    }

    public A withNewVolumeID(byte[] arg1,int arg2,int arg3) {
        return (A)withVolumeID(new String(arg1, arg2, arg3));
    }

    public A withNewVolumeID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withVolumeID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewVolumeID(String arg1) {
        return (A)withVolumeID(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AWSElasticBlockStoreVolumeSourceFluentImpl that = (AWSElasticBlockStoreVolumeSourceFluentImpl) o;
        if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
        if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        if (volumeID != null ? !volumeID.equals(that.volumeID) :that.volumeID != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fsType,  partition,  readOnly,  volumeID,  super.hashCode());
    }

}
